/* miniRIPE database scheme for PostgreSQL */
/* nichdl table */
CREATE TABLE nichdl (id_nichdl BIGSERIAL NOT NULL UNIQUE, "nichdl" VARCHAR(11) NOT NULL PRIMARY KEY UNIQUE,
 	form_order INTEGER NOT NULL DEFAULT 0);
/* source table */
CREATE TABLE source (id_source SERIAL NOT NULL UNIQUE, source VARCHAR(256) NOT NULL PRIMARY KEY UNIQUE);
INSERT INTO source (source) VALUES ('miniRIPE');

/* Maintainer object */
CREATE TABLE mntner (id_mntner BIGSERIAL NOT NULL UNIQUE, mntner VARCHAR(11) NOT NULL PRIMARY KEY UNIQUE, id_source INTEGER REFERENCES source(id_source) NOT NULL);
CREATE TABLE mntner_descr (id_descr BIGSERIAL NOT NULL, id_mntner INTEGER REFERENCES mntner(id_mntner) NOT NULL,
	descr VARCHAR(256));
CREATE TABLE mntner_adminc (id_adminc BIGSERIAL NOT NULL, id_mntner INTEGER REFERENCES mntner(id_mntner) NOT NULL,
 	adminc INTEGER REFERENCES nichdl(id_nichdl) NOT NULL, form_order INTEGER DEFAULT 0);
CREATE TABLE mntner_techc (id_techc BIGSERIAL NOT NULL, id_mntner INTEGER REFERENCES mntner(id_mntner) NOT NULL,
 	techc INTEGER REFERENCES nichdl(id_nichdl) NOT NULL, form_order INTEGER DEFAULT 0);
/* ToDo - auth */
CREATE TABLE mntner_auth (id_auth BIGSERIAL NOT NULL, id_mntner INTEGER REFERENCES mntner(id_mntner) NOT NULL,
	auth TEXT NOT NULL, form_order INTEGER DEFAULT 0);
CREATE TABLE mntner_remarks (id_remarks BIGSERIAL NOT NULL, id_mntner INTEGER REFERENCES mntner(id_mntner) NOT NULL,
 	remarks VARCHAR(256) NOT NULL, form_order INTEGER DEFAULT 0);
CREATE TABLE mntner_notify (id_notify BIGSERIAL NOT NULL, id_mntner INTEGER REFERENCES mntner(id_mntner) NOT NULL,
 	notify VARCHAR(320) NOT NULL, form_order INTEGER DEFAULT 0);
CREATE TABLE mntner_mntby (id_mntby BIGSERIAL NOT NULL, id_mntner INTEGER REFERENCES mntner(id_mntner) NOT NULL,
 	mntby INTEGER REFERENCES mntner(id_mntner), form_order INTEGER DEFAULT 0);
CREATE TABLE mntner_changed (id_changed BIGSERIAL NOT NULL, id_mntner INTEGER REFERENCES mntner(id_mntner) NOT NULL,
 	changed VARCHAR(320) NOT NULL, changed_date TIMESTAMP, form_order INTEGER DEFAULT 0);

/* Person object */
CREATE TABLE person (id_person BIGSERIAL NOT NULL PRIMARY KEY UNIQUE, person VARCHAR(128) UNIQUE NOT NULL,
 	id_nichdl INTEGER REFERENCES nichdl(id_nichdl) NOT NULL UNIQUE, id_source INTEGER REFERENCES source(id_source) NOT NULL);
CREATE TABLE person_address (id_address BIGSERIAL NOT NULL, id_person INTEGER REFERENCES person(id_person) NOT NULL,
 	address VARCHAR(256) NOT NULL, form_order INTEGER DEFAULT 0);
CREATE TABLE person_phone (id_phone BIGSERIAL NOT NULL, id_person INTEGER REFERENCES person(id_person) NOT NULL,
 	phone VARCHAR(64) NOT NULL, form_order INTEGER DEFAULT 0);
CREATE TABLE person_faxno (id_faxno BIGSERIAL NOT NULL, id_person INTEGER REFERENCES person(id_person) NOT NULL,
 	faxno VARCHAR(64) NOT NULL, form_order INTEGER DEFAULT 0);
CREATE TABLE person_email (id_email BIGSERIAL NOT NULL, id_person INTEGER REFERENCES person(id_person) NOT NULL,
 	email VARCHAR(320) NOT NULL, form_order INTEGER DEFAULT 0);
CREATE TABLE person_remarks (id_remarks BIGSERIAL NOT NULL, id_person INTEGER REFERENCES person(id_person) NOT NULL,
 	remarks VARCHAR(256) NOT NULL, form_order INTEGER DEFAULT 0);
CREATE TABLE person_notify (id_notify BIGSERIAL NOT NULL, id_person INTEGER REFERENCES person(id_person) NOT NULL,
 	notify VARCHAR(320) NOT NULL, form_order INTEGER DEFAULT 0);
CREATE TABLE person_mntby (id_mntby BIGSERIAL NOT NULL, id_person INTEGER REFERENCES person(id_person) NOT NULL,
 	mntby INTEGER REFERENCES mntner(id_mntner), form_order INTEGER DEFAULT 0);
CREATE TABLE person_changed (id_changed BIGSERIAL NOT NULL, id_person INTEGER REFERENCES person(id_person) NOT NULL,
 	changed VARCHAR(320) NOT NULL, changed_date TIMESTAMP, form_order INTEGER DEFAULT 0);

/* Role object */
CREATE TABLE role (id_role BIGSERIAL NOT NULL PRIMARY KEY UNIQUE, role VARCHAR(128) NOT NULL UNIQUE, id_nichdl REFERENCES nichdl(id_nichdl)
 	NOT NULL UNIQUE, id_source INTEGER REFERENCES source(id_source) NOT NULL);
CREATE TABLE role_address (id_address BIGSERIAL NOT NULL, id_role INTEGER REFERENCES role(id_role) NOT NULL,
 	address VARCHAR(256) NOT NULL, form_order INTEGER DEFAULT 0);
CREATE TABLE role_phone (id_phone BIGSERIAL NOT NULL, id_role INTEGER REFERENCES role(id_role) NOT NULL,
 	phone VARCHAR(64) NOT NULL, form_order INTEGER DEFAULT 0);
CREATE TABLE role_faxno (id_faxno BIGSERIAL NOT NULL, id_role INTEGER REFERENCES role(id_role) NOT NULL,
 	faxno VARCHAR(64) NOT NULL, form_order INTEGER DEFAULT 0);
CREATE TABLE role_email (id_email BIGSERIAL NOT NULL, id_role INTEGER REFERENCES role(id_role) NOT NULL,
 	email VARCHAR(320) NOT NULL, form_order INTEGER DEFAULT 0);
CREATE TABLE role_trouble (id_trouble BIGSERIAL NOT NULL, id_role INTEGER REFERENCES role(id_role) NOT NULL,
 	trouble VARCHAR(256) NOT NULL, form_order INTEGER DEFAULT 0);
CREATE TABLE role_adminc (id_adminc BIGSERIAL NOT NULL, id_role INTEGER REFERENCES role(id_role) NOT NULL,
 	adminc INTEGER REFERENCES nichdl(id_nichdl) NOT NULL, form_order INTEGER DEFAULT 0);
CREATE TABLE role_techc (id_techc BIGSERIAL NOT NULL, id_role INTEGER REFERENCES role(id_role) NOT NULL,
 	techc INTEGER REFERENCES nichdl(id_nichdl) NOT NULL, form_order INTEGER DEFAULT 0);
CREATE TABLE role_remarks (id_remarks BIGSERIAL NOT NULL, id_role INTEGER REFERENCES role(id_role) NOT NULL,
 	remarks VARCHAR(256) NOT NULL, form_order INTEGER DEFAULT 0);
CREATE TABLE role_notify (id_notify BIGSERIAL NOT NULL, id_role INTEGER REFERENCES role(id_role) NOT NULL,
 	notify VARCHAR(320) NOT NULL, form_order INTEGER DEFAULT 0);
CREATE TABLE role_mntby (id_mntby BIGSERIAL NOT NULL, id_role INTEGER REFERENCES role(id_role) NOT NULL,
 	mntby INTEGER REFERENCES mntner(id_mntner), form_order INTEGER DEFAULT 0);
CREATE TABLE role_changed (id_changed BIGSERIAL NOT NULL, id_role INTEGER REFERENCES role(id_role) NOT NULL,
 	changed VARCHAR(320) NOT NULL, changed_date TIMESTAMP, form_order INTEGER DEFAULT 0);

/* MySQL doesn't have CIDR data type */
/*
CREATE TABLE inetnum (id_inetnum INTEGER NOT NULL AUTO_INCREMENT, inetnum_ip INTEGER UNSIGNED NOT NULL PRIMARY KEY UNIQUE, inetnum_mask SMALLINT NOT NULL, netname VARCHAR(128) NOT NULL, descr TEXT NOT NULL, country TEXT NOT NULL, adminc TEXT NOT NULL, techc TEXT NOT NULL, revsrv TEXT, notify TEXT, mntby TEXT NOT NULL, mntlower TEXT, mntroutes TEXT, changed TEXT NOT NULL, source VARCHAR(3));
CREATE TABLE inetnum_descr
CREATE TABLE inetnum_country (id_inetcountry BIGSERIAL NOT NULL, country CHAR(2) NOT NULL, form_order INTEGER DEFAULT 0);
CREATE TABLE inetnum_adminc (id_adminc BIGSERIAL NOT NULL, id_inetnum INTEGER REFERENCES inetnum(id_inetnum) NOT NULL,
	adminc INTEGER REFERENCES nichdl(id_nichdl) NOT NULL, form_order INTEGER REFERENCES inetnum(id_inetnum) DEFAULT 0);
CREATE TABLE inetnum_techc (id_techc BIGSERIAL NOT NULL, id_inetnum INTEGER REFERENCES inetnum(id_inetnum) NOT NULL,
	techc INTEGER REFERENCES nichdl(id_nichdl) NOT NULL, form_order INTEGER REFERENCES inetnum(id_inetnum) DEFAULT 0);
CREATE TABLE inetnum_notify (id_notify BIGSERIAL NOT NULL, id_inetnum INTEGER REFERENCES inetnum(id_inetnum) NOT NULL,
 	notify VARCHAR(320) NOT NULL, form_order INTEGER DEFAULT 0);
CREATE TABLE inetnum_mntby
CREATE TABLE inetnum_mntlower
CREATE TABLE inetnum_mntroutes
CREATE TABLE inetnum_changed (id_changed BIGSERIAL NOT NULL, id_inetnum INTEGER REFERENCES inetnum(id_inetnum) NOT NULL,
 	changed VARCHAR(320) NOT NULL, changed_date TIMESTAMP, form_order INTEGER DEFAULT 0);

CREATE TABLE autnum (id_autnum INTEGER NOT NULL AUTO_INCREMENT, autnum VARCHAR(7) NOT NULL PRIMARY KEY UNIQUE, asname VARCHAR(128) NOT NULL, descr TEXT NOT NULL, import TEXT, export TEXT, defaultroute TEXT, remarks TEXT, adminc TEXT NOT NULL, techc TEXT NOT NULL, notify TEXT, mntby TEXT NOT NULL, mntlower TEXT, changed TEXT NOT NULL, source VARCHAR(3));
CREATE TABLE autnum_descr
CREATE TABLE autnum_import
CREATE TABLE autnum_export
CREATE TABLE autnum_defaultroute
CREATE TABLE autnum_remarks
CREATE TABLE autnum_adminc
CREATE TABLE autnum_techc
CREATE TABLE autnum_notify
CREATE TABLE autnum_mntby
CREATE TABLE autnum_mntlower
CREATE TABLE autnum_changed

# MySQL nema CIDR
CREATE TABLE route (id_route INTEGER NOT NULL AUTO_INCREMENT, route INTEGER UNSIGNED NOT NULL UNIQUE PRIMARY KEY, netmask SMALLINT NOT NULL, descr TEXT NOT NULL, origin VARCHAR(7), remarks TEXT, notify TEXT, mntlower TEXT, mntroutes TEXT, mntby TEXT NOT NULL, changed TEXT NOT NULL, source VARCHAR(3));
CREATE TABLE route_desc
CREATE TABLE route_remarks
CREATE TABLE route_notify
CREATE TABLE route_mntlower
CREATE TABLE route_mntroutes
CREATE TABLE route_mntby
CREATE TABLE route_changed
/*
/*
# MySQL nema CIDR
CREATE TABLE inet6num (id_inet6num INTEGER NOT NULL AUTO_INCREMENT, inet6num_ip INTEGER UNSIGNED NOT NULL PRIMARY KEY UNIQUE, netname VARCHAR(128) NOT NULL, descr TEXT NOT NULL, country TEXT NOT NULL, adminc TEXT NOT NULL, techc TEXT NOT NULL, revsrv TEXT, notify TEXT, mntby TEXT NOT NULL, mntlower TEXT, mntroutes TEXT, changed TEXT NOT NULL, source VARCHAR(3));
CREATE TABLE inet6num_descr
CREATE TABLE inet6num_country
CREATE TABLE inet6num_adminc
CREATE TABLE inet6num_techc
CREATE TABLE inet6num_revsrv
CREATE TABLE inet6num_mntby
CREATE TABLE inet6num_mntlower
CREATE TABLE inet6num_mntroutes
CREATE TABLE inet6num_changed
*/
/*
# ToDo - domain, nserver
CREATE TABLE domain (id_domain INTEGER NOT NULL AUTO_INCREMENT, domain VARCHAR(255) NOT NULL PRIMARY KEY UNIQUE, descr TEXT NOT NULL, adminc TEXT NOT NULL, techc TEXT NOT NULL, zone-c TEXT NOT NULL, nserver VARCHAR(255), remarks TEXT, notify TEXT, mntby TEXT, changed TEXT NOT NULL, mntlower TEXT, source VARCHAR(3));
CREATE TABLE domain_descr
CREATE TABLE domain_adminc
CREATE TABLE domain_techc
CREATE TABLE domain_zone-c
CREATE TABLE domain_remarks
CREATE TABLE domain_notify
CREATE TABLE domain_mntby
CREATE TABLE domain_changed
CREATE TABLE domain_mntlower
*/
